lambeq.text2diagram
===================

.. automodule:: lambeq.text2diagram
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: ccg_type_regex, id_regex, escaped_words, tree_regex, verbose

.. autodata:: lambeq.text2diagram.cups_reader

.. autodata:: lambeq.text2diagram.spiders_reader

.. autodata:: lambeq.text2diagram.stairs_reader

.. autodata:: lambeq.text2diagram.word_sequence_reader

.. autodata:: lambeq.text2diagram.bag_of_words_reader
